==> igniteui-webcomponents-core-3.2.0.tgz: package/esm5/lib/WebThemeControllerDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebThemeControllerDescription } from "./WebThemeControllerDescription";
/**
 * @hidden
 */
var WebThemeControllerDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(WebThemeControllerDescriptionMetadata, _super);
    function WebThemeControllerDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebThemeControllerDescriptionMetadata.b = function (a) {
        if (WebThemeControllerDescriptionMetadata.a == null) {
            WebThemeControllerDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebThemeControllerDescriptionMetadata.c(WebThemeControllerDescriptionMetadata.a);
        }
        if (a.g(WebThemeControllerDescriptionMetadata.a)) {
            return;
        }
        a.s(WebThemeControllerDescriptionMetadata.a);
    };
    WebThemeControllerDescriptionMetadata.c = function (a) {
        a.item("__qualifiedNameTS", "String:ThemeController");
    };
    WebThemeControllerDescriptionMetadata.d = function (a) {
        WebThemeControllerDescriptionMetadata.b(a);
        a.u("WebThemeController", function () { return new WebThemeControllerDescription(); });
        a.t("WebThemeController", WebThemeControllerDescriptionMetadata.a);
    };
    WebThemeControllerDescriptionMetadata.$t = markType(WebThemeControllerDescriptionMetadata, 'WebThemeControllerDescriptionMetadata');
    WebThemeControllerDescriptionMetadata.a = null;
    return WebThemeControllerDescriptionMetadata;
}(Base));
export { WebThemeControllerDescriptionMetadata };

==> igniteui-webcomponents-core-3.5.0.tgz: package/esm5/lib/WebThemeControllerDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebThemeControllerDescription } from "./WebThemeControllerDescription";
/**
 * @hidden
 */
var WebThemeControllerDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(WebThemeControllerDescriptionMetadata, _super);
    function WebThemeControllerDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebThemeControllerDescriptionMetadata.b = function (a) {
        if (WebThemeControllerDescriptionMetadata.a == null) {
            WebThemeControllerDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebThemeControllerDescriptionMetadata.c(WebThemeControllerDescriptionMetadata.a);
        }
        if (a.j(WebThemeControllerDescriptionMetadata.a)) {
            return;
        }
        a.y(WebThemeControllerDescriptionMetadata.a);
    };
    WebThemeControllerDescriptionMetadata.c = function (a) {
        a.item("__qualifiedNameTS", "String:ThemeController");
    };
    WebThemeControllerDescriptionMetadata.d = function (a) {
        WebThemeControllerDescriptionMetadata.b(a);
        a.aa("WebThemeController", function () { return new WebThemeControllerDescription(); });
        a.z("WebThemeController", WebThemeControllerDescriptionMetadata.a);
    };
    WebThemeControllerDescriptionMetadata.$t = markType(WebThemeControllerDescriptionMetadata, 'WebThemeControllerDescriptionMetadata');
    WebThemeControllerDescriptionMetadata.a = null;
    return WebThemeControllerDescriptionMetadata;
}(Base));
export { WebThemeControllerDescriptionMetadata };
